@@ -7,9 +7,16 @@ OPTIONS = 'OPTIONS'
 
 
 class JWTPlugin:
-    def __init__(self, secret: str, verify: bool = True, mapper: dict = None):
+    def __init__(
+        self,
+        secret: str,
+        verify: bool = True,
+        mapper: dict = None,
+        algorithm: str = 'RS256',
+    ):
         self._secret = secret
         self._verify = verify
+        self._algorithm = algorithm
         self._mapper = mapper if mapper else {}
 
     def __call__(self, handler):
@@ -20,7 +27,10 @@ class JWTPlugin:
             token = auth_header[7:]
             try:
                 decoded = jwt.decode(
-                    token, self._secret, options={'verify_signature': self._verify}
+                    token,
+                    self._secret,
+                    options={'verify_signature': self._verify},
+                    algorithms=[self._algorithm],
                 )
                 for k, v in self._mapper.items():
                     if k in decoded:
